FlexColorSeedColorExtensions extension

Public extensions on Color.

Convenience Color sRGB extensions that can be used as none deprecated replacements for alpha, red, green, blue and value they are called alpha8bit, red8bit, green8bit, blue8bit and value32bit. FlexSeedScheme uses them to avoid using the deprecated color properties.

on

Properties

alpha8bit int

Available on Color, provided by the FlexColorSeedColorExtensions extension

The alpha channel of this color in an 8 bit value.
no setter
blue8bit int

Available on Color, provided by the FlexColorSeedColorExtensions extension

The blue channel of this color in an 8 bit value.
no setter
green8bit int

Available on Color, provided by the FlexColorSeedColorExtensions extension

The green channel of this color in an 8 bit value.
no setter
red8bit int

Available on Color, provided by the FlexColorSeedColorExtensions extension

The red channel of this color in an 8 bit value.
no setter
value32bit int

Available on Color, provided by the FlexColorSeedColorExtensions extension

A 32 bit value representing this color.
no setter